diff --git a/spring-data-commons-core/src/test/java/org/springframework/data/repository/core/support/QueryExecuterMethodInterceptorUnitTests.java b/spring-data-commons-core/src/test/java/org/springframework/data/repository/core/support/QueryExecutorMethodInterceptorUnitTests.java
similarity index 82%
rename from spring-data-commons-core/src/test/java/org/springframework/data/repository/core/support/QueryExecuterMethodInterceptorUnitTests.java
rename to spring-data-commons-core/src/test/java/org/springframework/data/repository/core/support/QueryExecutorMethodInterceptorUnitTests.java
index a89c59e5b..a2e386dcf 100644
--- a/spring-data-commons-core/src/test/java/org/springframework/data/repository/core/support/QueryExecuterMethodInterceptorUnitTests.java
+++ b/spring-data-commons-core/src/test/java/org/springframework/data/repository/core/support/QueryExecutorMethodInterceptorUnitTests.java
@@ -23,8 +23,6 @@ import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;
import org.springframework.data.repository.core.RepositoryInformation;
-import org.springframework.data.repository.core.support.RepositoryFactorySupport;
-import org.springframework.data.repository.core.support.RepositoryFactorySupport.QueryExecuterMethodInterceptor;
import org.springframework.data.repository.query.QueryLookupStrategy.Key;
/**
@@ -33,7 +31,7 @@ import org.springframework.data.repository.query.QueryLookupStrategy.Key;
* @author Oliver Gierke
*/
@RunWith(MockitoJUnitRunner.class)
-public class QueryExecuterMethodInterceptorUnitTests {
+public class QueryExecutorMethodInterceptorUnitTests {
@Mock
RepositoryFactorySupport factory;
@@ -46,7 +44,7 @@ public class QueryExecuterMethodInterceptorUnitTests {
when(information.hasCustomMethod()).thenReturn(true);
when(factory.getQueryLookupStrategy(any(Key.class))).thenReturn(null);
- factory.new QueryExecuterMethodInterceptor(information, null, new Object());
+ factory.new QueryExecutorMethodInterceptor(information, null, new Object());
}
@Test
@@ -55,7 +53,7 @@ public class QueryExecuterMethodInterceptorUnitTests {
when(information.hasCustomMethod()).thenReturn(false);
when(factory.getQueryLookupStrategy(any(Key.class))).thenReturn(null);
- factory.new QueryExecuterMethodInterceptor(information, null, new Object());
+ factory.new QueryExecutorMethodInterceptor(information, null, new Object());
verify(information, times(0)).getQueryMethods();
}
}
diff --git a/spring-data-commons-core/src/main/java/org/springframework/data/repository/core/support/RepositoryFactorySupport.java b/spring-data-commons-core/src/main/java/org/springframework/data/repository/core/support/RepositoryFactorySupport.java
index 6c404579f..e4644ca6f 100644
--- a/spring-data-commons-core/src/main/java/org/springframework/data/repository/core/support/RepositoryFactorySupport.java
+++ b/spring-data-commons-core/src/main/java/org/springframework/data/repository/core/support/RepositoryFactorySupport.java
@@ -86,7 +86,7 @@ public abstract class RepositoryFactorySupport {
/**
* Adds {@link RepositoryProxyPostProcessor}s to the factory to allow
* manipulation of the {@link ProxyFactory} before the proxy gets created.
* Note that the {@link QueryExecuterMethodInterceptor} will be added to the
* proxy after the {@link RepositoryProxyPostProcessor}s are
* considered.
*
@@ -144,7 +144,7 @@ public abstract class RepositoryFactorySupport {
processor.postProcess(result);
}
- result.addAdvice(new QueryExecuterMethodInterceptor(information,
+ result.addAdvice(new QueryExecutorMethodInterceptor(information,
customImplementation, target));
return (T) result.getProxy();
@@ -251,7 +251,7 @@ public abstract class RepositoryFactorySupport {
*
* @author Oliver Gierke
*/
- public class QueryExecuterMethodInterceptor implements MethodInterceptor {
+ public class QueryExecutorMethodInterceptor implements MethodInterceptor {
private final Map queries =
new ConcurrentHashMap();
@@ -262,11 +262,11 @@ public abstract class RepositoryFactorySupport {
/**
* Creates a new {@link QueryExecuterMethodInterceptor}. Builds a model
* of {@link QueryMethod}s to be invoked on execution of repository
* interface methods.
*/
- public QueryExecuterMethodInterceptor(
+ public QueryExecutorMethodInterceptor(
RepositoryInformation repositoryInformation,
Object customImplementation, Object target) {
@@ -86,7 +86,7 @@ public abstract class RepositoryFactorySupport {
* Adds {@link RepositoryProxyPostProcessor}s to the factory to allow
* manipulation of the {@link ProxyFactory} before the proxy gets created.
- * Note that the {@link QueryExecuterMethodInterceptor} will be added to the
+ * Note that the {@link QueryExecutorMethodInterceptor} will be added to the
* proxy after the {@link RepositoryProxyPostProcessor}s are
* considered.
@@ -262,11 +262,11 @@ public abstract class RepositoryFactorySupport {
/**
- * Creates a new {@link QueryExecuterMethodInterceptor}. Builds a model
+ * Creates a new {@link QueryExecutorMethodInterceptor}. Builds a model
* of {@link QueryMethod}s to be invoked on execution of repository
* interface methods.